Stan Math Library: stan/math/fwd/scal/fun/value_of.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

value_of.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_VALUE_OF_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_VALUE_OF_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 namespace stan {
7 namespace math {
8
15 template<typename T>
16 inline T value_of(const fvar<T>& v) {
17 return v.val_;
18 }
19
20 }
21 }
22 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::value_of
T value_of(const fvar< T > &v)
Return the value of the specified variable.
Definition: value_of.hpp:16
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.